@@ -226,17 +226,22 @@ class requests_plus():
         return False
 
     @staticmethod
-    def get_picture(url, reqNum=1, savePath=r'.', saveName=r'', isDownload=True, **kwargs):
+    def get_picture(url, reqNum=1, savePath=r'.', saveName=r'', isDownload=True, log=False, **kwargs):
+        printer = lambda *args, **kwargs: print(*args, **kwargs) if log else False
+        saveName = saveName or time.strftime("%Y%m%d-%H%M%S.png")
+        if isDownload and os.path.exists(fr'{savePath}/{saveName}'):
+            print(fr'{savePath}/{saveName} 存在')
+            return False
         browserhead = {'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/87.0.4280.66 Safari/537.36'}
         for _ in range(reqNum):
             try:
                 req = requests.get(url=url, headers=kwargs.get('headers', browserhead), **kwargs)
                 if req.status_code == 200:
                     if isDownload:
-                        open(fr'{savePath}/{saveName or time.strftime("%Y%m%d-%H%M%S.png")}', 'wb').write(req.content)
+                        open(fr'{savePath}/{saveName}', 'wb').write(req.content)
                     return req
             except Exception as e:
-                pass
+                printer(e)
         return False
 
 
